use deltalake::SchemaTypeStruct;

#[tokio::test]
async fn test_create_table() -> Result<(), anyhow::Error> {
    let table_dir = tempfile::tempdir()?;
    let table_url = carto::filepath_to_url(&table_dir.into_path())?;

    let yaml = r#"
---
type: struct
fields:
  - name: timestamp
    type: timestamp
    nullable: false
    metadata:
    "#;

    let schema: SchemaTypeStruct = serde_yaml::from_str(yaml)?;
    let _ = carto::create_table_with_schema(table_url.clone(), schema.clone()).await?;
    let mut loaded = deltalake::open_table(table_url).await?;
    loaded.load().await?;
    let loaded_schema = loaded.schema().unwrap();
    assert_eq!(loaded_schema, &schema);
    Ok(())
}

#[tokio::test]
async fn test_update_table() -> Result<(), anyhow::Error> {
    let table_dir = tempfile::tempdir()?;
    let table_url = carto::filepath_to_url(&table_dir.into_path())?;

    let yaml = r#"
---
type: struct
fields:
  - name: timestamp
    type: timestamp
    nullable: false
    metadata:
    "#;

    let schema: SchemaTypeStruct = serde_yaml::from_str(yaml)?;
    let _ = carto::create_table_with_schema(table_url.clone(), schema.clone()).await?;

    let update_yaml = r#"
---
type: struct
fields:
  - name: timestamp
    type: timestamp
    nullable: false
    metadata:
  - name: message
    type: string
    nullable: false
    metadata:
    "#;

    let schema: SchemaTypeStruct = serde_yaml::from_str(update_yaml)?;
    let _ = carto::update_table_with_schema(table_url.clone(), schema.clone()).await?;

    let mut loaded = deltalake::open_table(table_url).await?;
    loaded.load().await?;
    let loaded_schema = loaded.schema().unwrap();
    assert_eq!(loaded_schema, &schema);
    Ok(())
}
